spacepy.toolbox.logspace — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »

# spacepy.toolbox.logspace

`spacepy.toolbox.` `logspace`(min, max, num, **kwargs)

  Returns log-spaced bins. Same as numpy.logspace except the min and max are the min and max not log10(min) and log10(max)

  Parameters: | min : float minimum value max : float maximum value num : integer number of log spaced bins
  Returns: | out : array log-spaced bins from min to max in a numpy array
  Other Parameters:
  | kwargs : dict additional keywords passed into matplotlib.dates.num2date

  See also

  `geomspace`, `linspace`

  Notes

  This function works on both numbers and datetime objects

  Examples

      >>> import spacepy.toolbox as tb
      >>> tb.logspace(1, 100, 5)
      array([   1.        ,    3.16227766,   10.        ,   31.6227766 ,  100.        ])

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- toolbox - Toolbox of various functions and generic utilities »